toolCalls property

List<AIChatMessageToolCall> get toolCalls

The list of tool that the model wants to call. If the model does not want to call any tool, this list will be empty.

Implementation

List<AIChatMessageToolCall> get toolCalls =>
    content.whereType<AIChatMessageToolCall>().toList(growable: false);