isMergeable property

bool isMergeable
final

Whether later streaming chunks may be merged into this block.

Set this to false when the provider requires the exact boundary of a completed content part to be retained.

Implementation

final bool isMergeable;