AIChatMessageFileBlock class final

A provider-hosted file block.

Inheritance
Annotations
  • @immutable

Constructors

AIChatMessageFileBlock({required String uri, String? name, String? mimeType, String id = '', int? index, bool isMergeable = true, Map<String, dynamic> providerData = const {}})
Creates a file block.
const
AIChatMessageFileBlock.fromMap(Map<String, dynamic> map)
Converts a map to a file block.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
Stable provider identifier for this block, when available.
finalinherited
index int?
Position assigned to this block by the provider's streaming protocol.
finalinherited
isMergeable bool
Whether later streaming chunks may be merged into this block.
finalinherited
mimeType String?
Optional file MIME type.
final
name String?
Optional file name.
final
providerData Map<String, dynamic>
Provider-specific data, nested under a provider namespace.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamIdentity String?
A stable identity that can be used to merge streamed chunks.
no setterinherited
uri String
URI that identifies the file.
final

Methods

canMerge(AIChatMessageContentBlock other) bool
Whether other is a chunk of the same logical streaming block.
inherited
concat(AIChatMessageContentBlock other) AIChatMessageContentBlock
Merges a later streaming chunk into this block.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts this block to a map.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(covariant AIChatMessageFileBlock other) bool
The equality operator.
override