ChatMessageContentImage class

The content of a message that is an image.

Inheritance

Constructors

ChatMessageContentImage({required String data, String? mimeType, ChatMessageContentImageDetail detail = ChatMessageContentImageDetail.auto})
The content of a message that is an image.
const
ChatMessageContentImage.fromMap(Map<String, dynamic> map)
Converts a map to a ChatMessageContentImage.
factory

Properties

data → String
Depending on the model, this can be either:
final
detail → ChatMessageContentImageDetail
Specifies the detail level of the image.
final
hashCode → int
The hash code for this object.
no setteroverride
mimeType → String?
The IANA standard MIME type of the source data. The accepted types vary per model.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts this ChatMessageContent to a map along with a type hint for deserialization.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant ChatMessageContentImage other) → bool
The equality operator.
override