ChatMessageContentMultiModal class

{@template chat_message_content_multi_modal} The content of a message that is multi-modal. {@endtemplate

Inheritance
Annotations
  • @immutable

Constructors

ChatMessageContentMultiModal({required List<ChatMessageContent> parts})
ChatMessageContentMultiModal.fromMap(Map<String, dynamic> map)
Converts a map to a ChatMessageContentMultiModal.
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
parts → List<ChatMessageContent>
The parts of the multi-modal message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts ChatMessageContentMultiModal to a map along with a type hint for deserialization.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant ChatMessageContentMultiModal other) → bool
The equality operator.
override