ChatModelOptions class abstract

Generation options to pass into the Chat Model.

Inheritance
Implementers
Annotations
  • @immutable

Constructors

ChatModelOptions({String? model, List<ToolSpec>? tools, ChatToolChoice? toolChoice, int concurrencyLimit = 1000})
Generation options to pass into the Chat Model.
const

Properties

concurrencyLimit → int
The maximum number of concurrent calls that the runnable can make. Defaults to 1000 (different Runnable types may have different defaults).
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
model → String?
ID of the language model to use. Check the provider's documentation for available models.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolChoice → ChatToolChoice?
Controls which (if any) tool is called by the model.
final
tools → List<ToolSpec>?
A list of tools the model may call.
final

Methods

copyWith({String? model, List<ToolSpec>? tools, ChatToolChoice? toolChoice, int? concurrencyLimit}) → ChatModelOptions
Creates a copy of this RunnableOptions with the given fields replaced by the new values.
override
merge(RunnableOptions? other) → RunnableOptions
Merges this RunnableOptions with another RunnableOptions.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(covariant RunnableOptions other) → bool
The equality operator.
inherited