PromptException class final

Exception thrown when some error occurs while working with a prompt.

Inheritance

Constructors

PromptException({String? message = ''})
Exception thrown when some error occurs while working with a prompt.
const

Properties

code → String
The optional code to accommodate the message.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String?
The long form message of the exception.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace which provides information to the user about the call sequence that triggered an exception
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(covariant LangChainException other) → bool
The equality operator.
inherited