AIChatMessageReasoningBlock class final
A reasoning or thinking block that is not visible model output.
- Inheritance
-
- Object
- AIChatMessageContentBlock
- AIChatMessageReasoningBlock
- Annotations
-
- @immutable
Constructors
-
AIChatMessageReasoningBlock({required String reasoning, String id = '', int? index, bool isMergeable = true, Map<
String, dynamic> providerData = const {}}) -
Creates a reasoning block.
const
-
AIChatMessageReasoningBlock.fromMap(Map<
String, dynamic> map) -
Converts a map to a reasoning block.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
Stable provider identifier for this block, when available.
finalinherited
- index → int?
-
Position assigned to this block by the provider's streaming protocol.
finalinherited
- isMergeable → bool
-
Whether later streaming chunks may be merged into this block.
finalinherited
-
providerData
→ Map<
String, dynamic> -
Provider-specific data, nested under a provider namespace.
finalinherited
- reasoning → String
-
The reasoning text.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamIdentity → String?
-
A stable identity that can be used to merge streamed chunks.
no setterinherited
Methods
-
canMerge(
AIChatMessageContentBlock other) → bool -
Whether
otheris a chunk of the same logical streaming block.inherited -
concat(
AIChatMessageContentBlock other) → AIChatMessageContentBlock -
Merges a later streaming chunk into this block.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
Converts this block to a map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
covariant AIChatMessageReasoningBlock other) → bool -
The equality operator.
override